@@ -1,3 +1,13 @@
+# from rest_framework.pagination import PageNumberPagination
+
+# class CustomPagination(PageNumberPagination):
+#     page_query_param = 'p'
+#     page_size_query_param = 'page_size'
+
+#     def __init__(self, page_size=None, max_page_size=None):
+#         self.page_size = page_size
+#         self.max_page_size = max_page_size
+
 from rest_framework.pagination import PageNumberPagination
 
 class CustomPagination(PageNumberPagination):
@@ -12,6 +22,7 @@ class CustomPagination(PageNumberPagination):
     def paginate_data(self, data, request):
         self.page = request.query_params.get(self.page_query_param, 1)
         self.page_size = self._get_page_size(request)
+        self.count = len(data)  # set count attribute
         paginated_data = self.paginate_queryset(data, request)
         return paginated_data
 
