@@ -10,7 +10,7 @@ class BaseAPIView(APIView):
         serializer = APIResponseSerializer({
             'success': True,
             'status': status,
-            'data': data
+            'results': data
         })
         return Response(serializer.data, status=status)
 
@@ -28,7 +28,7 @@ class StandardAPIView(BaseAPIView):
         serializer = APIResponseSerializer({
             'success': True,
             'status': status,
-            'data': data
+            'results': data
         })
         return Response(serializer.data, status=status)
 
@@ -50,7 +50,7 @@ class StandardAPIView(BaseAPIView):
                 'count': paginator.count,
                 'next': paginator.get_next_link(),
                 'previous': paginator.get_previous_link(),
-                'data': paginated_data
+                'results': paginated_data
             })
             return Response(serializer.data)
         except Exception as e:
